@@ -58,17 +58,26 @@ def disp(msg):
     else:
         print(msg)
 
+def str_disp(msg):
+    return f"{msg}\n"
+
 def disp_par(msg):
     if type_of_script() == 'jupyter':
         display(HTML(f"<p>{msg}</p>"))
     else:
         print(f"\nmsg\n")
 
+def str_disp_par(msg):
+    return f"\n{msg}\n"
+
 def disp_bold(msg):
     if type_of_script() == 'jupyter':
         display(HTML(f"<b>{msg}</b>"))
     else:
         print(f"**{msg}**")
+
+def str_disp_bold(msg):
+    return f"**{msg}**"
     
 def disp_bold_par(msg):
     if type_of_script() == 'jupyter':
@@ -76,23 +85,35 @@ def disp_bold_par(msg):
     else:
         print(f"\n**{msg}**\n")
 
+def str_disp_bold_par(msg):
+    return f"\n**{msg}**\n"
+
 def disp_h1(msg):
     if type_of_script() == 'jupyter':
         display(HTML(f"<h1>{msg}</h1>"))
     else:
         print(f"\n# {msg}\n")
 
+def str_disp_h1(msg):    
+    return f"\n# {msg}\n"
+
 def disp_h2(msg):
     if type_of_script() == 'jupyter':
         display(HTML(f"<h2>{msg}</h2>"))
     else:
         print(f"\n## {msg}\n")
 
+def str_disp_h2(msg):
+    return f"\n## {msg}\n"
+
 def disp_h3(msg):
     if type_of_script() == 'jupyter':
         display(HTML(f"<h3>{msg}</h3>"))
     else:
-        print(f"\n## {msg}\n")
+        print(f"\n### {msg}\n")
+
+def str_disp_h3(msg):
+    return f"\n### {msg}\n"
 
 def disp_array(a, headers=[], fmt=".4e", tablefmt="psql", showindex=False):
     """
@@ -103,6 +124,12 @@ def disp_array(a, headers=[], fmt=".4e", tablefmt="psql", showindex=False):
     else:
         print(tab.tabulate(np.asarray(a), tablefmt=tablefmt, floatfmt=fmt, showindex=showindex, headers=headers))
 
+def str_disp_array(a, headers=[], fmt=".4e", tablefmt="psql", showindex=False):
+    """
+    Return a numpy array in a nice way as a string.
+    """
+    return tab.tabulate(np.asarray(a), tablefmt=tablefmt, floatfmt=fmt, showindex=showindex, headers=headers)
+
 class ElementProperties(object):
     def __init__(self):
         self.ep = {}
